@@ -1,5 +1,5 @@
 import os
-from sqlalchemy import create_engine, Column, Text, SmallInteger
+from sqlalchemy import create_engine, Column, Text, SmallInteger, Integer, TIMESTAMP
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
@@ -58,11 +58,17 @@ class TSDatabase():
     def _create_view_class(self, base):
         class View(base):
             __tablename__ = 'views'
-            __table_args__ = ({'autoload': True})
+            time = COLUMN(TIMESTAMP, primary_key=True)
+            movie_id = COLUMN(Text)
+            user_id = COLUMN(Text, primary_key=True)
+            minute = COLUMN(Integer)
         return View
     
     def _create_rating_class(self, base):
         class Rating(base):
             __tablename__ = 'views'
-            __table_args__ = ({'autoload': True})
+            time = COLUMN(TIMESTAMP, primary_key=True)
+            movie_id = COLUMN(Text)
+            user_id = COLUMN(Text, primary_key=True)
+            rating = COLUMN(SmallInteger)
         return Rating
\ No newline at end of file
